@@ -1,5 +1,5 @@
 #!/usr/bin/python2.5
-# versione 1.7
+# versione 1.8
 # ui di configurazione per savepu
 # by m750 at smartphonetab.net
 # patch for v50 by peter leinchen
@@ -14,8 +14,8 @@ from PyQt4.QtCore import *
 from savecpu_ui import *
 
 
-Global_Version = '2.21.17-1'
-UI_Version = '1.5'
+Global_Version = '2.22.18-1'
+UI_Version = '1.8'
 
 try:
     _fromUtf8 = QtCore.QString.fromUtf8
@@ -34,7 +34,7 @@ class About(QtGui.QMainWindow):
         aboutScrollArea = QScrollArea(self)
         aboutScrollArea.setWidgetResizable(True)
         awidget = QWidget(aboutScrollArea)
-        awidget.setMinimumSize(200,500)
+        awidget.setMinimumSize(200,520)
         awidget.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding )
         aboutScrollArea.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding )
 
@@ -42,8 +42,8 @@ class About(QtGui.QMainWindow):
 
         aboutLabel = QLabel('''<center><b>savecpu</b> %s
                <br>Application for N900 with Titan's/Pali's kernel and active overclock.
-               <br>It works in background, watching the temperature (no more through the
-               <br><b>bq27200</b> module).
+               <br>It works in background, watching the temperature through the
+               <br><b>bq27200</b> or <b>i2c</b>(thank's to Peter Leinchen) modules.
                <br>
                <br></center>With this interface it's possible to set:
                <br> - LED colors
@@ -189,9 +189,13 @@ class MyForm(QtGui.QMainWindow):
                 time.sleep(0.1)
                 #temperatura = os.popen('cat /sys/class/power_supply/bq27200-0/temp').read()
                 ###temperatura = os.popen('cat /sys/devices/platform/omap34xx_temp/temp1_input').read()
-                temperatura = os.popen('echo $(sudo i2cget -y 2 0x55 0x06 w) | awk \'{ printf ($1*0.25-273)*100 }\'').read()
+                bq = os.popen('lsmod | grep bq27x00').read()
+                if str(bq.strip())!='':
+                  temperatura = os.popen('echo $(cat /sys/class/power_supply/bq27200-0/temp)0').read()
+                else:
+                  temperatura = os.popen('echo $(sudo i2cget -y 2 0x55 0x06 w) | awk \'{ printf ($1*0.25-273)*100 }\'').read()
                 # kernel v47
-                print temperatura
+                #print temperatura
                 #temperatura=temperatura.strip()
                 #print temperatura
                 #if len(temperatura) == 3 :
@@ -200,14 +204,17 @@ class MyForm(QtGui.QMainWindow):
                 temperatura = (int(temperatura) + 50) / 100
 
                 temperatura=str(temperatura)    
-                print temperatura
+                #print temperatura
 
 
 
 
 
-                ###check = os.popen('ps -ef | grep /opt/savecpu/savecpu.sh | awk \'/start/ {print $7}\'').read()
-                check = os.popen('ps -ef | grep /opt/savecpu/savecpu.sh | awk \'/start/ {print $8}\'').read()
+                bb = os.popen('readlink /usr/sbin/watchdog').read()
+                if str(bb.strip())=='/bin/busybox': 
+                  check = os.popen('ps -ef | grep /opt/savecpu/savecpu.sh | awk \'/start/ {print $8}\'').read()
+                else:
+                  check = os.popen('ps -ef | grep /opt/savecpu/savecpu.sh | awk \'/start/ {print $7}\'').read()
                 check=check.strip()
 
                 #print check
