@@ -1,7 +1,6 @@
 #!/bin/sh
 # savecpu
-# versione 2.21 by m750 at smartphonetab.net
-# lettura conf da file
+# version 2.22 by m750 at smartphonetab.net
 # patch for v50 by peter leinchen
 
 
@@ -87,7 +86,12 @@ do
   #echo $massima
   #temperatura=`cat /sys/class/power_supply/bq27200-0/temp`
   ###temperatura=`cat /sys/devices/platform/omap34xx_temp/temp1_input | awk '{ sub(/-/,""); print $1+7}'`
-  temperatura=`echo $(i2cget -y 2 0x55 0x06 w) | awk '{ printf ($1*0.25-273)*100 }'`
+  if [ -n "$(lsmod | grep bq27x00)" ]
+  then
+    temperatura=`echo $(cat /sys/class/power_supply/bq27200-0/temp)0`
+  else
+    temperatura=`echo $(i2cget -y 2 0x55 0x06 w) | awk '{ printf ($1*0.25-273)*100 }'`
+  fi
   temperatura=`expr \( $temperatura + 50 \) \/ 100`
   echo "temp: " $temperatura
 
@@ -202,3 +206,5 @@ exit 0
 #
 
 #
+
+#
